@@ -53,16 +53,17 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-06-17'; # DATE
+our $DATE = '2023-07-28'; # DATE
 our $DIST = 'TableData-Acme-CPANModules'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 with 'TableDataRole::Acme::CPANModules';
 
 # STATS
 
 1;
-# ABSTRACT: Entries from a Acme::CPANModules::* module
+# PODNAME: TableData::Acme::CPANModules
+# ABSTRACT: Entries from an Acme::CPANModules::* module
 
 __END__
 
@@ -72,11 +73,11 @@ __END__
 
 =head1 NAME
 
-TableDataRole::Acme::CPANModules - Entries from a Acme::CPANModules::* module
+TableData::Acme::CPANModules - Entries from an Acme::CPANModules::* module
 
 =head1 VERSION
 
-This document describes version 0.002 of TableDataRole::Acme::CPANModules (from Perl distribution TableData-Acme-CPANModules), released on 2023-06-17.
+This document describes version 0.003 of TableDataRole::Acme::CPANModules (from Perl distribution TableData-Acme-CPANModules), released on 2023-07-28.
 
 =head1 SYNOPSIS
 
